==> hinemos_src-3.2.2.tar.gz: VendorSrc/NTSyslog-1.15-R2-Hinemos/NTSyslog/convert.h <==
/*-----------------------------------------------------------------------------
 *
 *  convert.h - R[hϊW[ wb_t@C
 *
 *    Copyright (c) 2003, Ryo.Sugahara / Algorithm Collection
 *                                        All rights reserved
 *
 *    {W[Weby[WuAlgorithm CollectionvɌfڂꂽ̂𗬗p
 *    č\̂łB
 *
 *    Algorithm Collection
 *      http://alfin.mine.utsunomiya-u.ac.jp/~niy/algo/index.html
 *
 *    This program is free software; you can redistribute it and/or
 *    modify it under the terms of the GNU General Public License
 *    as published by the Free Software Foundation; either version 2
 *    of the License, or (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307
 *
 *  Revision history:
 *    16-Apr-2003  
 *
 *----------------------------------------------------------------------------*/

/* R[hʂ̔*/
extern int whatKanji(unsigned char *str);
/* pJiSpJiɕϊ */
extern unsigned int hankaku2zen(int hankaku);
/* pJiSpJiɕϊiΉŁj*/
extern int han2zen(unsigned int *zenkaku, unsigned char *str);
/* VtgJISR[hJISR[hɕϊ */
extern unsigned int sjis2jis(unsigned int sjis);
/* VtgJISR[hEUCR[hɕϊ */
extern unsigned int sjis2euc(unsigned int sjis);
/* JISR[hVtgJISR[hɕϊ */
extern unsigned int jis2sjis(unsigned int jis);
/* JISR[hEUCR[hɕϊ */
extern unsigned int jis2euc(unsigned int jis);
/* EUCR[hJISR[hɕϊ */
extern unsigned int euc2jis(unsigned int euc);
/* _R[hJISR[hɕϊ */
extern unsigned int kuten2jis(unsigned int kuten);
/* JISR[h_R[hɕϊ */
extern unsigned int jis2kuten(unsigned int jis);

==> hinemos_src-4.0.3.tar.gz: VendorSrc/NTSyslog-1.15-R2-Hinemos/NTSyslog/convert.h <==
/*-----------------------------------------------------------------------------
 *
 *  convert.h - 文字コード変換モジュール ヘッダファイル
 *
 *    Copyright (c) 2003, Ryo.Sugahara / Algorithm Collection
 *                                        All rights reserved
 *
 *    本モジュールはWebページ「Algorithm Collection」に掲載されたものを流用し
 *    再構成したものです。
 *
 *    Algorithm Collection
 *      http://alfin.mine.utsunomiya-u.ac.jp/~niy/algo/index.html
 *
 *    This program is free software; you can redistribute it and/or
 *    modify it under the terms of the GNU General Public License
 *    as published by the Free Software Foundation; either version 2
 *    of the License, or (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307
 *
 *  Revision history:
 *    16-Apr-2003  初版
 *
 *----------------------------------------------------------------------------*/

/* 文字コード種別の判定*/
extern int whatKanji(unsigned char *str);
/* 半角カナを全角カナに変換する */
extern unsigned int hankaku2zen(int hankaku);
/* 半角カナを全角カナに変換する（濁音対応版）*/
extern int han2zen(unsigned int *zenkaku, unsigned char *str);
/* シフトJISコードをJISコードに変換する */
extern unsigned int sjis2jis(unsigned int sjis);
/* シフトJISコードをEUCコードに変換する */
extern unsigned int sjis2euc(unsigned int sjis);
/* JISコードをシフトJISコードに変換する */
extern unsigned int jis2sjis(unsigned int jis);
/* JISコードをEUCコードに変換する */
extern unsigned int jis2euc(unsigned int jis);
/* EUCコードをJISコードに変換する */
extern unsigned int euc2jis(unsigned int euc);
/* 句点コードをJISコードに変換する */
extern unsigned int kuten2jis(unsigned int kuten);
/* JISコードを句点コードに変換する */
extern unsigned int jis2kuten(unsigned int jis);
